# Alerts

- What this package is used for
- How to install and import
- How to use it
- Functions
    - Info
    - Warning
    - Error
    - Success
    - Prmise
- Parameters

<hr />

## What this package is used for

This package uses [react-toastify](https://www.npmjs.com/package/react-toastify) to create alerts across all the app, and react-redux to tell the alert component that should show an alert.

It contains a component, "AlertProvider", that adds the toastify component to the web page.

Even though it does not needs any parameter, it needs a store of [@redux/toolkit](https://www.npmjs.com/package/@reduxjs/toolkit) to add the reducers that this package contains.

## How to install and import

To install it use `npm install @jgedff/alert_provider` or `yarn add @jgedff/alert_provider`

All the components, reducers and functions can be imported with `import { AlertProvider } from '@jgedff/alert_provider'`

## How to use it

Once you install it, you nedd a store of redux.

This store needs to configure a store with the property **middleware**, that it has to be set to an array function, that as a parameter has an input named **getDefaultMiddleware**.

This parameter is a function that must be executed with an object as a parameter. This object has a property named **serializableCheck**, and this property must be setted as another object that contains the properties **ignoreState** and **ignoreActions** as true.

Finally, outside the middleware property and still inside the configureStore property, you have to add the **reducer** property and set it as an object.

This object needs a property with the name **alert** and set it with the **alertReducer** that you will have to import from the package.

Here is the code of how it should look like with.

`
import { alertReducer } from "@jgedff/alert_provider";

export default configureStore({
  middleware: (getDefaultMiddleware) =>
    getDefaultMiddleware({
      serializableCheck: {
        ignoreState: true,
        ignoreActions: true
      }
    }),
  reducer: {
    alert: alertReducer,
  }
})
`

With this configuration, you will just need to add the **AlertProvider** where you execute the dispatch for the alerts.

In order to add the **AlertProvider**, you have to import it, and then put the app or the components that will call the alerts inside like an HTML tag.

`
ReactDOM.createRoot(document.getElementById('root')!).render(
  <>
    `<AlertProvider>
      <App />
    </AlertProvider>`
  </>
)
`

## Functions

This package has 5 diferent alerts, and they are called using one function each type of alert.

All of this alerts use the functions from the **alertReducer**, so when you call it, you will have to call it using the useDispatch from redux.

### Info alert

The function that calls the info alert is called **info**.

You can import it with `import { info } from '@jgedff/alert_provider'`

It needs a **string as a parameter**

`
import { useDispatch } from 'react-redux'
import { info } from '@jgedff/alert_provider'

export const Component = (): JSX.Element => {
  const dispatch = useDispatch()

  const callInfoAlert = (): void => {
    dispatch(info('This alert show an alert with some information'))
  }

  return (
    `<button onClick={callInfoAlert}>Alert Info</button>`
  )
}
`

### Warning alert

The function that calls the warning alert is called **warning**.

You can import it with `import { warning } from '@jgedff/alert_provider'`

It needs a **string as a parameter**

`
import { useDispatch } from 'react-redux'
import { warning } from '@jgedff/alert_provider'

export const Component = (): JSX.Element => {
  const dispatch = useDispatch()

  const callWarningAlert = (): void => {
    dispatch(warning('This alert show a warning'))
  }

  return (
    `<button onClick={callWarningAlert}>Warning alert</button>`
  )
}
`

### Error alert

The function that calls the error alert is called **setError**.

You can import it with `import { setError } from '@jgedff/alert_provider'`

It needs a **string as a parameter**

`
import { useDispatch } from 'react-redux'
import { setError } from '@jgedff/alert_provider'

export const Component = (): JSX.Element => {
  const dispatch = useDispatch()

  const callErrorAlert = (): void => {
    dispatch(setError('This alert show an error alert'))
  }

  return (
    `<button onClick={callErrorAlert}>Error alert</button>`
  )
}
`

### Success alert

The function that calls the success alert is called **success**.

You can import it with `import { success } from '@jgedff/alert_provider'`

It needs a **string as a parameter**

`
import { useDispatch } from 'react-redux'
import { success } from '@jgedff/alert_provider'

export const Component = (): JSX.Element => {
  const dispatch = useDispatch()

  const callSuccessAlert = (): void => {
    dispatch(success('This alert show a success alert'))
  }

  return (
    `<button onClick={callSuccessAlert}>Success alert</button>`
  )
}
`

### Promise alert

The promise alert, is an alert that while loads something shows a message, and when it ends, if ends with a sucess, will show a success alert, and if it ends with an error, it will show an error alert.

The function that calls the it is named **pormise**.

You can import it with `import { pormise } from '@jgedff/alert_provider'`

It needs an **object as a parameter**

This object needs the property **promise** setted as a **promise function**, and the property **config**, that needs to be an **object** that contains the properties **pending, success and error**, and all of them, needs a string to show the text while loading, when it succeeds and when there is an error.

`
import { useDispatch } from 'react-redux'
import { promise } from '@jgedff/alert_provider'

export const Component = (): JSX.Element => {
  const dispatch = useDispatch()

  const dataLoader = async (): Promise`<void>` => {
    await fetch('http://localhost:9999/api/createUser', {
      method: 'POST',
      headers: {
          'Content-Type': 'application/json'
      },
      body: JSON.stringify(credentials)
      })
  }

  const callPromiseAlert = (): void => {
    dispatch(promise({
      promise: dataLoader(),
      config: {
        pending: 'Creating user...',
        success: 'The user was created!',
        error: 'There was an error while creating the user.'
      }
    }))
  }

  return (
    <>
      `<button onClick={callPromiseAlert}>Promise alert</button>`
    </>
  )
}
`

## Parameters

| Function   | Parameters | Description                                       |
|:-----------|:----------:|--------------------------------------------------:|
| info()     | String     | Shows the string parameter inside a blue alert.   |
| warning()  | String     | Shows the string parameter inside a yellow alert. |
| setError() | String     | Shows the string parameter inside a red alert.    |
| success()  | String     | Shows the string parameter inside a green alert.  |
| promise()  | { promise: Promise<void>, config: { pending: String, error: String, success: String } } | While the promise is executed, the pending string will be shown in a white alert. When it succeeds, the success string will be shown in a green alert, and if it has an error, ti will show the error string in a red alert. |